ENCODER_VERBOSE = "verbose"
PATH_DESC = "path_desc"

ENCODER_PARAMS = "params"

ENCODER_TYPE_TFIDF = "tfidf"

ENCODER_TYPE_BERT_CLIENT = "bert_client"

ENCODER_TYPE = "type"

CACHE_PARAMS = "params"

CACHE_TYPE_SIMPLE = "simple"

CACHE_TYPE = "type"

CACHE_DESC = "cache"

PATH_OS_ENV = "os_env"

PATH_FILE_NAME = "file"

PATH_TYPE_ABSOLUTE = "absolute"

PATH_TYPE_RELATIVE = "relative"

PATH_TYPE = "type"

ENCODER_OUTPUT_DIM = "output_dim"

ENCODER_INPUT_DIM = "input_dim"

ENCODER_TYPE_COMPOSITE = "composite"

ENCODER_COMPOSITE_ENCODER_LIST = "encoders"

ENCODER_TYPE_BERT_EMBEDDED = "bert_embedded"

BERT_EMBEDDED_GRAPH = "graph"
BERT_EMBEDDED_VOCAB = "vocab"
BERT_EMBEDDED_MAX_SEQ_LEN = "seq_len"
